@@ -5,6 +5,7 @@ class Endpoints:
     Buddies = BASE + "buddies"
     BuddyLevels = Buddies + "/levels"
     Bundles = BASE + "bundles"
+    Ceremonies = BASE + "ceremonies"
     ContentTiers = BASE + "contenttiers"
     Currencies = BASE + "currencies"
     GameMode = BASE + "gamemodes"
@@ -26,3 +27,4 @@ class Endpoints:
     Contracts = BASE + "contracts"
     Events = BASE + "events"
     Gears = BASE + "gear"
+    LevelBorders = BASE + "levelborders"
